@@ -4,7 +4,7 @@
  * 		Query deparser for mysql_fdw
  *
  * Portions Copyright (c) 2012-2014, PostgreSQL Global Development Group
- * Portions Copyright (c) 2004-2023, EnterpriseDB Corporation.
+ * Portions Copyright (c) 2004-2024, EnterpriseDB Corporation.
  *
  * IDENTIFICATION
  * 		deparse.c
@@ -30,11 +30,7 @@
 #include "nodes/nodeFuncs.h"
 #include "nodes/plannodes.h"
 #include "optimizer/clauses.h"
-#if PG_VERSION_NUM < 120000
-#include "optimizer/var.h"
-#else
 #include "optimizer/optimizer.h"
-#endif
 #include "optimizer/prep.h"
 #include "optimizer/tlist.h"
 #include "parser/parsetree.h"
@@ -109,12 +105,8 @@ static void deparseExpr(Expr *expr, deparse_expr_cxt *context);
 static void mysql_deparse_var(Var *node, deparse_expr_cxt *context);
 static void mysql_deparse_const(Const *node, deparse_expr_cxt *context);
 static void mysql_deparse_param(Param *node, deparse_expr_cxt *context);
-#if PG_VERSION_NUM < 120000
-static void mysql_deparse_array_ref(ArrayRef *node, deparse_expr_cxt *context);
-#else
 static void mysql_deparse_array_ref(SubscriptingRef *node,
 									deparse_expr_cxt *context);
-#endif
 static void mysql_deparse_func_expr(FuncExpr *node, deparse_expr_cxt *context);
 static void mysql_deparse_op_expr(OpExpr *node, deparse_expr_cxt *context);
 static void mysql_deparse_operator_name(StringInfo buf,
@@ -610,39 +602,6 @@ mysql_deparse_column_ref(StringInfo buf, int varno, int varattno,
 	appendStringInfoString(buf, mysql_quote_identifier(colname, '`'));
 }
 
-static void
-mysql_deparse_string(StringInfo buf, const char *val, bool isstr)
-{
-	const char *valptr;
-	int			i = 0;
-
-	if (isstr)
-		appendStringInfoChar(buf, '\'');
-
-	for (valptr = val; *valptr; valptr++, i++)
-	{
-		char		ch = *valptr;
-
-		/*
-		 * Remove '{', '}', and \" character from the string. Because this
-		 * syntax is not recognize by the remote MySQL server.
-		 */
-		if ((ch == '{' && i == 0) || (ch == '}' && (i == (strlen(val) - 1))) ||
-			ch == '\"')
-			continue;
-
-		if (isstr && ch == ',')
-		{
-			appendStringInfoString(buf, "', '");
-			continue;
-		}
-		appendStringInfoChar(buf, ch);
-	}
-
-	if (isstr)
-		appendStringInfoChar(buf, '\'');
-}
-
 /*
 * Append a SQL string literal representing "val" to buf.
 */
@@ -692,13 +651,8 @@ deparseExpr(Expr *node, deparse_expr_cxt *context)
 		case T_Param:
 			mysql_deparse_param((Param *) node, context);
 			break;
-#if PG_VERSION_NUM < 120000
-		case T_ArrayRef:
-			mysql_deparse_array_ref((ArrayRef *) node, context);
-#else
 		case T_SubscriptingRef:
 			mysql_deparse_array_ref((SubscriptingRef *) node, context);
-#endif
 			break;
 		case T_FuncExpr:
 			mysql_deparse_func_expr((FuncExpr *) node, context);
@@ -1044,11 +998,7 @@ mysql_deparse_param(Param *node, deparse_expr_cxt *context)
  * Deparse an array subscript expression.
  */
 static void
-#if PG_VERSION_NUM < 120000
-mysql_deparse_array_ref(ArrayRef *node, deparse_expr_cxt *context)
-#else
 mysql_deparse_array_ref(SubscriptingRef *node, deparse_expr_cxt *context)
-#endif
 {
 	StringInfo	buf = context->buf;
 	ListCell   *lowlist_item;
@@ -1297,9 +1247,6 @@ mysql_deparse_scalar_array_op_expr(ScalarArrayOpExpr *node,
 	Expr	   *arg2;
 	Form_pg_operator form;
 	char	   *opname;
-	Oid			typoutput;
-	bool		typIsVarlena;
-	char	   *extval;
 
 	/* Retrieve information about the operator from system catalog. */
 	tuple = SearchSysCache1(OPEROID, ObjectIdGetDatum(node->opno));
@@ -1313,51 +1260,67 @@ mysql_deparse_scalar_array_op_expr(ScalarArrayOpExpr *node,
 	/* Deparse left operand. */
 	arg1 = linitial(node->args);
 	deparseExpr(arg1, context);
-	appendStringInfoChar(buf, ' ');
 
 	opname = NameStr(form->oprname);
 	if (strcmp(opname, "<>") == 0)
-		appendStringInfo(buf, " NOT ");
+		appendStringInfo(buf, " NOT");
 
 	/* Deparse operator name plus decoration. */
 	appendStringInfo(buf, " IN (");
 
 	/* Deparse right operand. */
 	arg2 = lsecond(node->args);
-	switch (nodeTag((Node *) arg2))
+	if (IsA(arg2, Const) && ((Const *) arg2)->constisnull)
 	{
-		case T_Const:
-			{
-				Const	   *c = (Const *) arg2;
-
-				if (c->constisnull)
-				{
-					appendStringInfoString(buf, " NULL");
-					ReleaseSysCache(tuple);
-					return;
-				}
-
-				getTypeOutputInfo(c->consttype, &typoutput, &typIsVarlena);
-				extval = OidOutputFunctionCall(typoutput, c->constvalue);
-
-				switch (c->consttype)
-				{
-					case INT4ARRAYOID:
-					case OIDARRAYOID:
-						mysql_deparse_string(buf, extval, false);
-						break;
-					default:
-						mysql_deparse_string(buf, extval, true);
-						break;
-				}
-			}
-			break;
-		default:
-			deparseExpr(arg2, context);
-			break;
+		appendStringInfoString(buf, "NULL");
 	}
-	appendStringInfoChar(buf, ')');
+	else if (IsA(arg2, Const))
+	{
+		Const	   *arrayconst = (Const *) arg2;
+		int 		i;
+		int			num_attr;
+		Datum	   *attr;
+		int16		elmlen;
+		bool		elmbyval;
+		bool		typIsVarlena;
+		char		elmalign;
+		Oid 		typOutput;
+		ArrayType  *arrayval;
+		bool	   *nullsp = NULL;
+		Oid			elemtype;
 
+		arrayval = DatumGetArrayTypeP(arrayconst->constvalue);
+		elemtype = ARR_ELEMTYPE(arrayval);
+		get_typlenbyvalalign(elemtype, &elmlen, &elmbyval, &elmalign);
+		deconstruct_array(arrayval, elemtype, elmlen, elmbyval,
+						  elmalign, &attr, &nullsp, &num_attr);
+		getTypeOutputInfo(elemtype, &typOutput, &typIsVarlena);
+
+		for (i = 0; i < num_attr; i++)
+		{
+			if (i != 0)
+				appendStringInfoString(buf, ", ");
+
+			if (nullsp[i])
+				appendStringInfoString(buf, "NULL");
+			else
+			{
+				char	   *str = OidOutputFunctionCall(typOutput, attr[i]);
+
+				/*
+				 * Do not quote values for int2, int4, int8, and oid array
+				 * elements.
+				 */
+				if (elemtype == INT2OID || elemtype == INT4OID ||
+					elemtype == INT8OID || elemtype == OIDOID)
+					appendStringInfoString(buf, str);
+				else
+					mysql_deparse_string_literal(buf, str);
+			}
+		}
+	}
+
+	appendStringInfoChar(buf, ')');
 	ReleaseSysCache(tuple);
 }
 
@@ -1591,15 +1554,9 @@ foreign_expr_walker(Node *node, foreign_glob_cxt *glob_cxt,
 					state = FDW_COLLATE_UNSAFE;
 			}
 			break;
-#if PG_VERSION_NUM < 120000
-		case T_ArrayRef:
-			{
-				ArrayRef   *ar = (ArrayRef *) node;
-#else
 		case T_SubscriptingRef:
 			{
 				SubscriptingRef *ar = (SubscriptingRef *) node;
-#endif
 
 				/* Should not be in the join clauses of the Join-pushdown */
 				if (glob_cxt->is_remote_cond)
@@ -1717,10 +1674,34 @@ foreign_expr_walker(Node *node, foreign_glob_cxt *glob_cxt,
 		case T_ScalarArrayOpExpr:
 			{
 				ScalarArrayOpExpr *oe = (ScalarArrayOpExpr *) node;
+				char	   *opname;
+				Node	   *arr = (Node *) lsecond(oe->args);
 
 				if (!mysql_check_remote_pushability(oe->opno))
 					return false;
 
+				/*
+				 * The number of elements in the array must be fixed, so that
+				 * it can be deparsed back to "foo IN (...)" form.
+				 */
+				if (!(IsA(arr, Const)))
+					return false;
+
+				opname = get_opname(oe->opno);
+
+				if (opname == NULL)
+					elog(ERROR, "cache lookup failed for operator %u", oe->opno);
+
+				/*
+				 * Don't push down ScalarArrayExprs (ANY and ALL), because
+				 * MySQL can't handle them.  Except when it's of the simple
+				 * "foo = ANY ('<constant>')" or "foo <> ALL ('<constant>')"
+				 * forms, and deparse that into "foo [NOT] IN (...)".
+				 */
+				if (!((strcmp(opname, "=") == 0 && oe->useOr) ||
+					  (strcmp(opname, "<>") == 0 && !oe->useOr)))
+					return false;
+
 				/*
 				 * Recurse to input subexpressions.
 				 */
