@@ -4,7 +4,7 @@
  * 		Type handling for remote MySQL servers
  *
  * Portions Copyright (c) 2012-2014, PostgreSQL Global Development Group
- * Portions Copyright (c) 2004-2023, EnterpriseDB Corporation.
+ * Portions Copyright (c) 2004-2024, EnterpriseDB Corporation.
  *
  * IDENTIFICATION
  * 		mysql_query.c
@@ -27,11 +27,7 @@
 #include "access/htup_details.h"
 #include "catalog/pg_type.h"
 #include "mysql_query.h"
-#if PG_VERSION_NUM < 120000
-#include "optimizer/var.h"
-#else
 #include "optimizer/optimizer.h"
-#endif
 #include "utils/builtins.h"
 #include "utils/date.h"
 #include "utils/datetime.h"
