@@ -529,6 +529,155 @@ EXPLAIN (VERBOSE, COSTS OFF)
 SELECT * FROM f_test_tbl1 t1 WHERE c1 = ANY(ARRAY[100, 200, c1 + 10000]);
 SELECT * FROM f_test_tbl1 t1 WHERE c1 = ANY(ARRAY[100, 200, c1 + 10000]);
 
+-- FDW:668 - MySQL's timestamp datatype should be mapped to PG's timestamptz.
+IMPORT FOREIGN SCHEMA mysql_fdw_regress LIMIT TO (timestamp_test)
+  FROM SERVER mysql_svr INTO public;
+SELECT attname, atttypid::regtype FROM pg_attribute
+  WHERE attrelid = 'timestamp_test'::regclass AND attnum >= 1 ORDER BY 1;
+
+SET timezone = 'Asia/Kolkata';
+INSERT INTO timestamp_test VALUES (1, '2020-01-01 00:00:00');
+INSERT INTO timestamp_test VALUES (2, '2020-01-01 00:00:00 +0:00');
+SET timezone = 'UTC';
+INSERT INTO timestamp_test VALUES (3, '2020-01-01 00:00:00');
+INSERT INTO timestamp_test VALUES (4, '2020-01-01 00:00:00 +5:30');
+SELECT * FROM timestamp_test ORDER BY 1;
+SET timezone = 'Asia/Kolkata';
+SELECT * FROM timestamp_test ORDER BY 1;
+
+
+-- FDW:692 - Scalar array operation with operator = ANY/<> ALL should pushdown.
+EXPLAIN (VERBOSE, COSTS FALSE)
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c1 = ANY ('{400, 4000}'::INT[])
+  ORDER BY c1;
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c1 = ANY ('{400, 4000}'::INT[])
+  ORDER BY c1;
+
+EXPLAIN (VERBOSE, COSTS FALSE)
+SELECT c1, c2, c4 FROM f_test_tbl1 e
+  WHERE c4 = ANY ('{400, NULL, 800}'::INT[])
+  ORDER BY c1;
+SELECT c1, c2, c4 FROM f_test_tbl1 e
+  WHERE c4 = ANY ('{400, NULL, 800}'::INT[])
+  ORDER BY c1;
+
+EXPLAIN (VERBOSE, COSTS FALSE)
+SELECT c1, c2, c4 FROM f_test_tbl1 e
+  WHERE c4 = ANY ('{400, 800}'::INT[])
+  ORDER BY c1;
+SELECT c1, c2, c4 FROM f_test_tbl1 e
+  WHERE c4 = ANY ('{400, 800}'::INT[])
+  ORDER BY c1;
+
+EXPLAIN (VERBOSE, COSTS FALSE)
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c1 != ALL ('{400, 4000}'::INT[])
+  ORDER BY c1;
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c1 != ALL ('{400, 4000}'::INT[])
+  ORDER BY c1;
+
+EXPLAIN (VERBOSE, COSTS FALSE)
+SELECT c1, c2, c4 FROM f_test_tbl1 e
+  WHERE c4 != ALL ('{400, NULL, 800}'::INT[])
+  ORDER BY c1;
+SELECT c1, c2, c4 FROM f_test_tbl1 e
+  WHERE c4 != ALL ('{400, NULL, 800}'::INT[])
+  ORDER BY c1;
+
+EXPLAIN (VERBOSE, COSTS FALSE)
+SELECT c1, c2, c4 FROM f_test_tbl1 e
+  WHERE c4 != ALL ('{400, 800}'::INT[])
+  ORDER BY c1;
+SELECT c1, c2, c4 FROM f_test_tbl1 e
+  WHERE c4 != ALL ('{400, 800}'::INT[])
+  ORDER BY c1;
+
+-- Scalar array operation with other than operator =/<> should not pushdown.
+EXPLAIN (VERBOSE, COSTS FALSE)
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c1 > ANY ('{400, 4000}'::INT[])
+  ORDER BY c1;
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c1 > ANY ('{400, 4000}'::INT[])
+  ORDER BY c1;
+
+EXPLAIN (VERBOSE, COSTS FALSE)
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c1 < ANY (ARRAY[100, 200, 500])
+  ORDER BY c1;
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c1 < ANY (ARRAY[100, 200, 500])
+  ORDER BY c1;
+
+EXPLAIN (VERBOSE, COSTS FALSE)
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c1 > ALL (ARRAY[100, 200, 500])
+  ORDER BY c1;
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c1 > ALL (ARRAY[100, 200, 500])
+  ORDER BY c1;
+
+-- Scalar array operation with = ALL/<> ANY should not pushdown.
+EXPLAIN (VERBOSE, COSTS FALSE)
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c1 != ANY (ARRAY[100, 200, 500])
+  ORDER BY c1;
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c1 != ANY (ARRAY[100, 200, 500])
+  ORDER BY c1;
+
+EXPLAIN (VERBOSE, COSTS FALSE)
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c1 = ALL ('{400, 500}'::INT[])
+  ORDER BY c1;
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c1 = ALL ('{400, 500}'::INT[])
+  ORDER BY c1;
+
+-- FDW-693: ScalarArrayOpExpr with multidimensional array should pushdown.
+EXPLAIN (VERBOSE, COSTS FALSE)
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c2 = ANY('{{EMP2, EMP4}, {EMP3, EMP7}, {NULL, EMP8}}'::TEXT[])
+  ORDER BY c1;
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c2 = ANY('{{EMP2, EMP4}, {EMP3, EMP7}, {NULL, EMP8}}'::TEXT[])
+  ORDER BY c1;
+
+EXPLAIN (VERBOSE, COSTS FALSE)
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c1 = ANY('{{100, 400}, {300, 500}, {NULL, 4000}}'::INT[])
+  ORDER BY c1;
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c1 = ANY('{{100, 400}, {300, 500}, {NULL, 4000}}'::INT[])
+  ORDER BY c1;
+
+EXPLAIN (VERBOSE, COSTS FALSE)
+SELECT c1, c2, c4, c6, c8 FROM f_test_tbl1 e
+  WHERE c4 = ANY('{{100, 400}, {300, 500}, {NULL, 4000}}'::INT8[])
+  ORDER BY c1;
+SELECT c1, c2, c4, c6, c8 FROM f_test_tbl1 e
+  WHERE c4 = ANY('{{100, 400}, {300, 600}, {NULL, 4000}}'::INT8[])
+  ORDER BY c1;
+
+EXPLAIN (VERBOSE, COSTS FALSE)
+SELECT c1, c2, c4, c6, c8 FROM f_test_tbl1 e
+  WHERE c6 = ANY('{{100, 400}, {300, 2850.00000}, {NULL, 1250.00000}}'::NUMERIC[])
+  ORDER BY c1;
+SELECT c1, c2, c4, c6, c8 FROM f_test_tbl1 e
+  WHERE c6 = ANY('{{100, 400}, {300, 2850.00000}, {NULL, 1250.00000}}'::NUMERIC[])
+  ORDER BY c1;
+
+EXPLAIN (VERBOSE, COSTS FALSE)
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c6 = ANY (ARRAY[400, 2850.00000])
+  ORDER BY c1;
+SELECT c1, c2, c6, c8 FROM f_test_tbl1 e
+  WHERE c6 = ANY (ARRAY[400, 2850.00000])
+  ORDER BY c1;
+
 -- Cleanup
 DROP TABLE l_test_tbl1;
 DROP TABLE l_test_tbl2;
@@ -541,6 +690,7 @@ DELETE FROM f_test_tbl1;
 DELETE FROM f_test_tbl2;
 DELETE FROM f_numbers;
 DELETE FROM f_enum_t1;
+DELETE FROM timestamp_test;
 DROP FOREIGN TABLE f_test_tbl1;
 DROP FOREIGN TABLE f_test_tbl2;
 DROP FOREIGN TABLE f_numbers;
@@ -554,6 +704,7 @@ DROP FOREIGN TABLE mysql_test;
 DROP FOREIGN TABLE test_tbl1;
 DROP FOREIGN TABLE f_test6;
 DROP FOREIGN TABLE f_test7;
+DROP FOREIGN TABLE timestamp_test;
 DROP TYPE size_t;
 DROP TYPE enum_t1_size_t;
 DROP TYPE enum_t2_size_t;
